@@ -1,8 +1,8 @@
-import pymafia.kolmafia as km
 from pymafia import ash
 from pymafia.combat import Macro
 from pymafia.datatypes import *
 from pymafia.iotms import *
+from pymafia.kolmafia import MafiaError, km
 from pymafia.player import *
 from pymafia.preference import *
 from pymafia.utils import *
