@@ -1,10 +1,11 @@
-from ._bounty import Bounty
+from pymafia.datatypes._bounty import Bounty
+
 from ._class import Class
 from ._coinmaster import Coinmaster
 from ._effect import Effect, EffectQuality
 from ._element import Element
 from ._familiar import Familiar
-from ._item import CandyType, Item, ItemQuality
+from ._item import CandyType, ConsumableQuality, Item
 from ._location import Location
 from ._monster import Monster
 from ._path import Path
