@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-import pymafia.kolmafia as km
+from pymafia.kolmafia import km
 
 if TYPE_CHECKING:
     from ._location import Location
@@ -75,8 +75,12 @@ class Bounty:
 
     @property
     def monster(self) -> Monster:
+        from ._monster import Monster
+
         return Monster(km.BountyDatabase.getMonster(self.name))
 
     @property
     def location(self) -> Location:
+        from ._location import Location
+
         return Location(km.BountyDatabase.getLocation(self.name))
