@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-import pymafia.kolmafia as km
+from pymafia.kolmafia import km
 
 if TYPE_CHECKING:
     from ._item import Item
@@ -51,6 +51,8 @@ class Coinmaster:
 
     @property
     def item(self) -> Item:
+        from ._item import Item
+
         if not self:
             return Item(None)
         item = self.coinmaster.getItem()
