@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-import pymafia.kolmafia as km
+from pymafia.kolmafia import km
 
 if TYPE_CHECKING:
     from ._item import Item
@@ -51,6 +51,8 @@ class Familiar:
 
     @property
     def hatchling(self) -> Item:
+        from ._item import Item
+
         return Item(km.FamiliarDatabase.getFamiliarLarva(self.id))
 
     @property
@@ -88,6 +90,8 @@ class Familiar:
 
     @property
     def drop_item(self) -> Item:
+        from ._item import Item
+
         item = km.FamiliarData.dropItem(self.id)
         return Item(item.getItemId() if item is not None else None)
 
