@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-import pymafia.kolmafia as km
+from pymafia.kolmafia import km
 
 if TYPE_CHECKING:
     from ._bounty import Bounty
@@ -89,6 +89,8 @@ class Location:
 
     @property
     def bounty(self) -> Bounty:
+        from ._bounty import Bounty
+
         if not self:
             return Bounty(None)
         bounty = km.AdventureDatabase.getBounty(self.adventure)
