@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from enum import Enum
 
 
@@ -10,18 +12,18 @@ class Stat(Enum):
     SUBMYSTICALITY = "SubMysticality"
     SUBMOXIE = "SubMoxie"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.value
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return self is not self.NONE
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value) -> Stat:
         if value is None:
             return cls.NONE
         return super()._missing_(value)
 
     @classmethod
-    def all(cls):
+    def all(cls) -> list[Stat]:
         return list(cls)
