@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-import pymafia.kolmafia as km
+from pymafia.kolmafia import km
 
 if TYPE_CHECKING:
     from ._skill import Skill
@@ -72,6 +72,8 @@ class Thrall:
 
     @property
     def skill(self) -> Skill:
+        from ._skill import Skill
+
         return Skill(self.data[3] if self else None)
 
     @property
